@@ -292,6 +292,12 @@ class OperationModel(object):
             return self._operation_data['x-form-factors'].split(',')
         return None
 
+    @CachedProperty
+    def extensions(self):
+        if "x-extensions" in self._operation_data:
+            return self._operation_data['x-extensions'].split(',')
+        return None
+
     @CachedProperty
     def input_shape(self):
         return self._service_model.resolve_shape_ref(
